# This file contains the WSGI configuration required to serve up your
# Django app
import os
import sys

# Add your project directory to the sys.path
settings_path = '{project.settings_path.parent.parent}'
sys.path.insert(0, settings_path)

# Set environment variable to tell django where your settings.py is
os.environ['DJANGO_SETTINGS_MODULE'] = '{project.settings_path.parent.name}.settings'

# Set the 'application' variable to the Django wsgi app
from django.core.wsgi import get_wsgi_application
application = get_wsgi_application()



#!/usr/bin/python
# Copyright (c) 2018 PythonAnywhere LLP.
# All Rights Reserved
#

## FIXME: this file is a pre-release copy of a built-in PythonAnywhere script.
## remove once the updated version is deployed to live.

import os
import sys

HOME = os.path.expanduser('~')
TMP = '/tmp'


def write_temporary_bashrc(virtualenv_path, unique_id, source_directory):
    bashrc_path = os.path.join(HOME, '.bashrc')
    if os.path.exists(bashrc_path):
        with open(bashrc_path) as f:
            bashrc = f.read()
    else:
        bashrc = ''
    if os.path.dirname(virtualenv_path) == os.path.join(HOME, '.virtualenvs'):
        activate_script = f'workon {os.path.basename(virtualenv_path)}'
    else:
        activate_script_path = os.path.join(virtualenv_path, 'bin', 'activate')
        if not os.path.exists(activate_script_path):
            print(f'Could not find virtualenv activation script at {activate_script_path}')
            sys.exit(-1)
        with open(activate_script_path) as f:
            activate_script = f.read()

    tmprc = os.path.join(TMP, f'tmprc.{unique_id}')
    with open(tmprc, 'w') as f:
        f.write(bashrc)
        f.write('\n')
        f.write(activate_script)
        f.write('\n')
        f.write(f'cd {source_directory}\n')
        f.write('\n')
        f.write(f'rm {tmprc}')
    return tmprc


def launch_bash_in_virtualenv(virtualenv_path, unique_id, source_directory):
    tmprc = write_temporary_bashrc(virtualenv_path, unique_id, source_directory)
    os.execv('/bin/bash', ['bash', '--rcfile', tmprc, '-i'])


if __name__ == '__main__':
    launch_bash_in_virtualenv(sys.argv[2], sys.argv[1], sys.argv[3])




"""User interface for PythonAnywhere scheduled tasks. Provides two
classes: `Task` and `TaskList` which should be used by helper scripts
providing features for programmatic handling of scheduled task."""

import logging

from pythonanywhere.api.schedule import Schedule
from pythonanywhere.snakesay import snakesay

logger = logging.getLogger(name=__name__)


class Task:
    """Class representing PythonAnywhere scheduled task.

    Bare instance of the `Task` is just a 'blueprint' for a scheduled
    task. This means the proper way to create an object representing
    existing existing task or a task ready to be created a `Task` instance
    should be created using classmethod constructors: `Task.from_id`,
    `Task.to_be_created` or Task.from_api_specs`.

    To create new task use :classmethod:`Task.to_be_created` and call
    :method:`Task.create_schedule` on it.

    To get an object representing existing task its id is needed. Having a
    valid id call :classmethod:`Task.from_id` and then execute other
    actions on the task:
    - to delete the task use :method:`Task.delete_schedule`,
    - to update the task use :method:`Task.update_schedule`.

    :classmethod:`Task.from_api_specs` is intended to to be called with
    specs returned by API and should not be used with arbitrary specs
    defined by user.

    `Task` class is API agnostic meaning all API calls are made using the
    `pythonanywhere.api.schedule.Schedule` interface via `Task.schedule`
    attribute."""

    def __init__(self):
        self.command = None
        self.hour = None
        self.minute = None
        self.interval = None
        self.enabled = None
        self.task_id = None
        self.can_enable = None
        self.expiry = None
        self.extend_url = None
        self.logfile = None
        self.printable_time = None
        self.url = None
        self.user = None
        self.schedule = Schedule()

    def __repr__(self):
        enabled = "enabled" if self.enabled else "disabled"
        status = (
            f"{enabled} at {self.printable_time}"
            if self.printable_time
            else "ready to be created"
        )
        num = f" <{self.task_id}>:" if self.task_id else ""

        return f"{self.interval.title()} task{num} '{self.command}' {status}"

    @classmethod
    def from_id(cls, task_id):
        """Creates representation of existing scheduled task by id.

        :param task_id: existing task id as integer
        :returns: `Task` instance with actual specs."""

        task = cls()
        specs = task.schedule.get_specs(task_id)
        task.update_specs(specs)
        return task

    @classmethod
    def to_be_created(cls, *, command, minute, hour=None, disabled=False):
        """Creates object ready to be created via API.

        To create the task call :method:`Task.create_schedule` on it.
        :param command: command executed by the task
        :param minute: minute on which task will be executed (required)
        :param hour: hour on which daily task will be executed
            (required by daily tasks)
        :param disabled: set to True to create disabled task (default
            is True meaning task will be created as enabled)
        :returns: `Task` instance ready to be created"""

        if hour is not None and not (0 <= hour <= 23):
            raise ValueError("Hour has to be in 0..23")
        if not (0 <= minute <= 59):
            raise ValueError("Minute has to be in 0..59")

        task = cls()
        task.command = command
        task.hour = hour
        task.minute = minute
        task.interval = "daily" if hour else "hourly"
        task.enabled = not disabled
        return task

    @classmethod
    def from_api_specs(cls, specs):
        """Create object representing scheduled task with specs returned by API.

        *Note* don't use this method in scripts. To create a new task use
        `Task.to_be_created` constructor.

        :param specs: spec dictionary returned by API.
        :returns: `Task` instance with actual specs."""

        task = cls()
        task.update_specs(specs)
        return task

    def update_specs(self, specs):
        """Sets `Task` instance's attributes using specs returned by API.

        *Note*: don't use this method in scripts.

        :param specs: spec dictionary returned by API."""

        for attr, value in specs.items():
            if attr == "id":
                attr = "task_id"
            setattr(self, attr, value)

    def create_schedule(self):
        """Creates new scheduled task.

        *Note* use this method on `Task.to_be_created` instance."""

        params = {
            "command": self.command,
            "enabled": self.enabled,
            "interval": self.interval,
            "minute": self.minute,
        }
        if self.hour:
            params["hour"] = self.hour

        self.update_specs(self.schedule.create(params))

        mode = "will" if self.enabled else "may be enabled to"
        msg = (
            "Task '{command}' successfully created with id {task_id} "
            "and {mode} be run {interval} at {printable_time}"
        ).format(
            command=self.command,
            task_id=self.task_id,
            mode=mode,
            interval=self.interval,
            printable_time=self.printable_time,
        )
        logger.info(snakesay(msg))

    def delete_schedule(self):
        """Deletes existing task.

        *Note*: use this method on `Task.from_id` instance."""

        if self.schedule.delete(self.task_id):
            logger.info(snakesay(f"Task {self.task_id} deleted!"))

    def update_schedule(self, params, *, porcelain=False):
        """Updates existing task using `params`.

        *Note*: use this method on `Task.from_id` instance.

        `params` should be one at least one of: command, enabled, interval,
        hour, minute. `interval` takes precedence over `hour` meaning that
        `hour` param will be ignored if `interval` is set to 'hourly'.

        :param params: dictionary of specs to update
        :param porcelain: when True don't use `snakesay` in stdout messages
            (defaults to False)"""

        specs = {
            "command": self.command,
            "enabled": self.enabled,
            "interval": self.interval,
            "hour": self.hour,
            "minute": self.minute,
        }

        specs.update(params)

        if (
            (specs["interval"] != "daily")
            or (params.get("interval") == "daily" and self.hour)
            or (params.get("hour") == self.hour)
        ):
            specs.pop("hour")

        if params.get("minute") == self.minute:
            specs.pop("minute")

        new_specs = self.schedule.update(self.task_id, specs)

        diff = {
            key: (getattr(self, key), new_specs[key])
            for key in specs
            if getattr(self, key) != new_specs[key]
        }

        def make_spec_str(key, old_spec, new_spec):
            return f"<{key}> from '{old_spec}' to '{new_spec}'"

        updated = [make_spec_str(key, val[0], val[1]) for key, val in diff.items()]

        def make_msg(join_with):
            fill = " " if join_with == ", " else join_with
            intro = f"Task {self.task_id} updated:{fill}"
            return f"{intro}{join_with.join(updated)}"

        if updated:
            if porcelain:
                logger.info(make_msg(join_with="\n"))
            else:
                logger.info(snakesay(make_msg(join_with=", ")))
            self.update_specs(new_specs)
        else:
            logger.warning(snakesay("Nothing to update!"))


class TaskList:
    """Creates user's tasks representation using `Task` class and specs
    returned by API.

    Tasks are stored in `TaskList.tasks` variable."""

    def __init__(self):
        self.tasks = [Task.from_api_specs(specs) for specs in Schedule().get_list()]



#!/usr/bin/python3

import typer

from pythonanywhere.django_project import DjangoProject
from pythonanywhere.snakesay import snakesay
from pythonanywhere.utils import ensure_domain

app = typer.Typer()


@app.command()
def autoconfigure(
    repo_url: str = typer.Argument(..., help="url of remote git repository of your django project"),
    domain_name: str = typer.Option(
        "your-username.pythonanywhere.com",
        "-d",
        "--domain",
        help="Domain name, eg www.mydomain.com",
    ),
    python_version: str = typer.Option(
        "3.6",
        "-p",
        "--python-version",
        help="Python version, eg '3.8'",
    ),
    nuke: bool = typer.Option(
        False,
        help="*Irrevocably* delete any existing web app config on this domain. Irrevocably.",
    ),
):
    """
    Autoconfigure a Django project from on a github URL.

    \b
    - downloads the repo
    - creates a virtualenv and installs django (or detects a requirements.txt if available)
    - creates webapp via api
    - creates django wsgi configuration file
    - adds static files config
    """
    domain = ensure_domain(domain_name)
    project = DjangoProject(domain, python_version)
    project.sanity_checks(nuke=nuke)
    project.download_repo(repo_url, nuke=nuke),
    project.create_virtualenv(nuke=nuke)
    project.create_webapp(nuke=nuke)
    project.add_static_file_mappings()
    project.find_django_files()
    project.update_wsgi_file()
    project.update_settings_file()
    project.run_collectstatic()
    project.run_migrate()
    project.webapp.reload()
    typer.echo(snakesay(f"All done!  Your site is now live at https://{domain_name}\n"))
    project.start_bash()


@app.command()
def start(
    domain_name: str = typer.Option(
        "your-username.pythonanywhere.com",
        "-d",
        "--domain",
        help="Domain name, eg www.mydomain.com",
    ),
    django_version: str = typer.Option(
        "latest",
        "-j",
        "--django-version",
        help="Django version, eg '3.1.2'",
    ),
    python_version: str = typer.Option(
        "3.6",
        "-p",
        "--python-version",
        help="Python version, eg '3.8'",
    ),
    nuke: bool = typer.Option(
        False,
        help="*Irrevocably* delete any existing web app config on this domain. Irrevocably.",
    ),
):
    """
    Create a new Django webapp with a virtualenv.  Defaults to
    your free domain, the latest version of Django and Python 3.6
    """
    domain = ensure_domain(domain_name)
    project = DjangoProject(domain, python_version)
    project.sanity_checks(nuke=nuke)
    project.create_virtualenv(django_version, nuke=nuke)
    project.run_startproject(nuke=nuke)
    project.find_django_files()
    project.update_settings_file()
    project.run_collectstatic()
    project.create_webapp(nuke=nuke)
    project.add_static_file_mappings()

    project.update_wsgi_file()

    project.webapp.reload()

    typer.echo(snakesay(f"All done!  Your site is now live at https://{domain}"))



#!C:\b\abs_a3b8nwbdr0\croots\recipe\pythonanywhere_1663667586853\_h_env\python.exe
import sys
import textwrap

MESSAGE = '\n'.join([
    '',
    '{bubble}',
    '   \\',
    '    ~<:>>>>>>>>>',

])


def snakesay(*things):
    bubble = '\n'.join(speech_bubble_lines(' '.join(things)))
    return MESSAGE.format(bubble=bubble)


def speech_bubble_lines(speech):
    lines, width = rewrap(speech)
    if len(lines) <= 1:
        text = ''.join(lines)
        yield f'< {text} >'

    else:
        yield '  ' + '_' * width
        yield '/ ' + (' ' * width) + ' \\'
        for line in lines:
            yield f'| {line} |'
        yield '\\ ' + (' ' * width) + ' /'
        yield '  ' + '-' * width


def rewrap(speech):
    lines = textwrap.wrap(speech)
    width = max(len(l) for l in lines) if lines else 0
    return [line.ljust(width) for line in lines], width



if __name__ == '__main__':
    print(snakesay(*sys.argv[1:]))



#!C:\b\abs_a3b8nwbdr0\croots\recipe\pythonanywhere_1663667586853\_h_env\python.exe
"""Update a scheduled task using id and proper specs.

Note that logfile name will change after updating the task but it won't be
created until first execution of the task.
To change interval from hourly to daily use --daily flag and provide --hour.
When --daily flag is not accompanied with --hour, new hour for the task
will be automatically set to current hour.
When changing interval from daily to hourly --hour flag is ignored.

Usage:
  pa_update_scheduled_task.py <id> [--command COMMAND]
                                   [--hour HOUR] [--minute MINUTE]
                                   [--disable | --enable | --toggle-enabled]
                                   [--daily | --hourly]
                                   [--quiet | --porcelain]

Options:
  -h, --help                  Print this message
  -c, --command COMMAND       Changes command to COMMAND (multiword commands
                              should be quoted)
  -o, --hour HOUR             Changes hour to HOUR (in 24h format)
  -m, --minute MINUTE         Changes minute to MINUTE
  -d, --disable               Disables task
  -e, --enable                Enables task
  -t, --toggle-enabled        Toggles enable/disable state
  -a, --daily                 Switches interval to daily (when --hour is not
                              provided, sets it automatically to current hour)
  -u, --hourly                Switches interval to hourly (takes precedence
                              over --hour, i.e. sets hour to None)
  -q, --quiet                 Turns off messages
  -p, --porcelain             Prints message in easy-to-parse format

Example:
  Change command for a scheduled task 42:

    pa_update_scheduled_task 42 --command "echo new command"

  Change interval of the task 42 from hourly to daily to be run at 10 am:

    pa_update_scheduled_task 42 --hour 10

  Change interval of the task 42 from daily to hourly and set new minute:

    pa_update_scheduled_task 42 --minute 13 --hourly"""

import logging
from datetime import datetime

from docopt import docopt

from pythonanywhere.scripts_commons import ScriptSchema, get_logger, get_task_from_id
from pythonanywhere.snakesay import snakesay


def main(*, task_id, **kwargs):
    logger = get_logger()

    if kwargs.pop("hourly"):
        kwargs["interval"] = "hourly"
    if kwargs.pop("daily"):
        kwargs["hour"] = kwargs["hour"] if kwargs["hour"] else datetime.now().hour
        kwargs["interval"] = "daily"

    def parse_opts(*opts):
        candidates = [key for key in opts if kwargs.pop(key, None)]
        return candidates[0] if candidates else None

    if not parse_opts("quiet"):
        logger.setLevel(logging.INFO)

    porcelain = parse_opts("porcelain")
    enable_opt = parse_opts("toggle_enabled", "disable", "enable")

    task = get_task_from_id(task_id)

    params = {key: val for key, val in kwargs.items() if val}
    if enable_opt:
        enabled = {"toggle_enabled": not task.enabled, "disable": False, "enable": True}[
            enable_opt
        ]
        params.update({"enabled": enabled})

    try:
        task.update_schedule(params, porcelain=porcelain)
    except Exception as e:
        logger.warning(snakesay(str(e)))


if __name__ == "__main__":
    schema = ScriptSchema(
        {
            "<id>": ScriptSchema.id_required,
            "--command": ScriptSchema.string,
            "--daily": ScriptSchema.boolean,
            "--disable": ScriptSchema.boolean,
            "--enable": ScriptSchema.boolean,
            "--hour": ScriptSchema.hour,
            "--hourly": ScriptSchema.boolean,
            "--minute": ScriptSchema.minute,
            "--porcelain": ScriptSchema.boolean,
            "--quiet": ScriptSchema.boolean,
            "--toggle-enabled": ScriptSchema.boolean,
        }
    )
    arguments = schema.validate_user_input(
        docopt(__doc__), conversions={"id": "task_id", "toggle-": "toggle_"}
    )

    main(**arguments)



#!/usr/bin/python3
import getpass
from enum import Enum
from pathlib import Path

import typer

from pythonanywhere.api.webapp import Webapp
from pythonanywhere.project import Project
from pythonanywhere.snakesay import snakesay
from pythonanywhere.utils import ensure_domain

app = typer.Typer()


@app.command()
def create(
    domain_name: str = typer.Option(
        "your-username.pythonanywhere.com",
        "-d",
        "--domain",
        help="Domain name, eg www.mydomain.com",
    ),
    python_version: str = typer.Option(
        "3.6",
        "-p",
        "--python-version",
        help="Python version, eg '3.8'",
    ),
    nuke: bool = typer.Option(
        False,
        help="*Irrevocably* delete any existing web app config on this domain. Irrevocably.",
    ),
):
    domain = ensure_domain(domain_name)
    project = Project(domain, python_version)
    project.sanity_checks(nuke=nuke)
    project.virtualenv.create(nuke=nuke)
    project.create_webapp(nuke=nuke)
    project.add_static_file_mappings()
    project.webapp.reload()

    typer.echo(
        snakesay(
            f"All done! Your site is now live at https://{domain}. "
            f"Your web app config screen is here: https://www.pythonanywhere.com/user/{getpass.getuser().lower()}"
            f"/webapps/{domain.replace('.', '_')}"
        )
    )


class LogType(str, Enum):
    access = "access"
    error = "error"
    server = "server"
    all = "all"


def index_callback(value: str):
    if value == "all" or (value.isnumeric() and int(value) in range(10)):
        return value
    raise typer.BadParameter(
        "log_index has to be 0 for current log, 1-9 for one of archive logs or all for all of them"
    )


@app.command()
def delete_logs(
    domain_name: str = typer.Option(
        "your-username.pythonanywhere.com",
        "-d",
        "--domain",
        help="Domain name, eg www.mydomain.com",
    ),
    log_type: LogType = typer.Option(
        LogType.all,
        "-t",
        "--log-type",
    ),
    log_index: str = typer.Option(
        "all",
        "-i",
        "--log-index",
        callback=index_callback,
        help="0 for current log, 1-9 for one of archive logs or all for all of them",
    ),
):
    webapp = Webapp(ensure_domain(domain_name))
    log_types = ["access", "error", "server"]
    logs = webapp.get_log_info()
    if log_type == "all" and log_index == "all":
        for key in log_types:
            for log in logs[key]:
                webapp.delete_log(key, log)
    elif log_type == "all":
        for key in log_types:
            webapp.delete_log(key, int(log_index))
    elif log_index == "all":
        for i in logs[log_type]:
            webapp.delete_log(log_type, int(i))
    else:
        webapp.delete_log(log_type, int(log_index))
    typer.echo(snakesay("All done!"))


@app.command()
def install_ssl(
    domain_name: str = typer.Argument(
        ...,
        help="Domain name, eg www.mydomain.com",
    ),
    certificate_file: Path = typer.Argument(
        ...,
        exists=True,
        file_okay=True,
        readable=True,
        resolve_path=True,
        help="The name of the file containing the combined certificate in PEM format (normally a number of blocks, "
        'each one starting "BEGIN CERTIFICATE" and ending "END CERTIFICATE")',
    ),
    private_key_file: Path = typer.Argument(
        ...,
        exists=True,
        file_okay=True,
        readable=True,
        resolve_path=True,
        help="The name of the file containing the private key in PEM format (a file with one block, "
        'starting with something like "BEGIN PRIVATE KEY" and ending with something like "END PRIVATE KEY")',
    ),
    suppress_reload: bool = typer.Option(
        False,
        help="The website will need to be reloaded in order to activate the new certificate/key combination "
        "-- this happens by default, use this option to suppress it.",
    ),
):
    with open(certificate_file, "r") as f:
        certificate = f.read()

    with open(private_key_file, "r") as f:
        private_key = f.read()

    webapp = Webapp(domain_name)
    webapp.set_ssl(certificate, private_key)
    if not suppress_reload:
        webapp.reload()

    ssl_details = webapp.get_ssl_info()
    typer.echo(
        snakesay(
            "That's all set up now :-)\n"
            f"Your new certificate for {domain_name} will expire\n"
            f"on {ssl_details['not_after'].date().isoformat()},\n"
            "so shortly before then you should renew it\n"
            "and install the new certificate."
        )
    )


@app.command()
def reload(
    domain_name: str = typer.Option(
        "your-username.pythonanywhere.com",
        "-d",
        "--domain",
        help="Domain name, eg www.mydomain.com",
    )
):
    domain_name = ensure_domain(domain_name)
    webapp = Webapp(domain_name)
    webapp.reload()
    typer.echo(snakesay(f"{domain_name} has been reloaded"))



#!C:\b\abs_a3b8nwbdr0\croots\recipe\pythonanywhere_1663667586853\_h_env\python.exe
"""Create a scheduled task.

Two categories of tasks are available: daily and hourly.
Both kinds require a command to run and scheduled time. In order to create a
daily task provide hour and minute; to create hourly task provide only minute.
If task is intended to be enabled later add --disabled flag.

Usage:
  pa_create_scheduled_task.py --command COMMAND [--hour HOUR] --minute MINUTE
                              [--disabled]

Options:
  -h, --help                  Prints this message
  -c, --command COMMAND       Task's command to be scheduled
  -o, --hour HOUR             Sets the task to be performed daily at HOUR
                              (otherwise the task will be run hourly)
  -m, --minute MINUTE         Minute on which the task will be executed
  -d, --disabled              Creates disabled task (otherwise enabled)

Example:
  Create a daily task to be run at 13:15:

    pa_create_scheduled_task.py --command "echo foo" --hour 13 --minute 15

  Create an inactive hourly task to be run 27 minutes past every hour:

    pa_create_scheduled_task.py --command "echo bar" --minute 27 --disabled

Note:
  Once task is created its behavior may be altered later on with
  `pa_update_scheduled_task.py` or deleted with `pa_delete_scheduled_task.py`
  scripts."""

from docopt import docopt

from pythonanywhere.scripts_commons import ScriptSchema, get_logger
from pythonanywhere.task import Task


def main(*, command, hour, minute, disabled):
    get_logger(set_info=True)
    hour = int(hour) if hour is not None else None
    task = Task.to_be_created(command=command, hour=hour, minute=int(minute), disabled=disabled)
    task.create_schedule()


if __name__ == "__main__":
    schema = ScriptSchema(
        {
            "--command": str,
            "--hour": ScriptSchema.hour,
            "--minute": ScriptSchema.minute,
            "--disabled": ScriptSchema.boolean,
        }
    )
    arguments = schema.validate_user_input(docopt(__doc__))

    main(**arguments)



#!C:\b\abs_a3b8nwbdr0\croots\recipe\pythonanywhere_1663667586853\_h_env\python.exe
"""Create a web app with a virtualenv

- creates a simple hello world web app
- creates a virtualenv for it and links the two
- creates a project folder for it at ~/www.domain-name.com
- sets up a default static files mapping for /static -> ~/domain.com/static

Usage:
  pa_create_webapp_with_virtualenv.py [--domain=<domain> --python=<python-version>] [--nuke]

Options:
  --domain=<domain>         Domain name, eg www.mydomain.com   [default: your-username.pythonanywhere.com]
  --python=<python-version> Python version, eg "3.8"    [default: 3.6]
  --nuke                    *Irrevocably* delete any existing web app config on this domain. Irrevocably.
"""

from docopt import docopt
import getpass
from textwrap import dedent

from pythonanywhere.project import Project
from pythonanywhere.snakesay import snakesay
from pythonanywhere.utils import ensure_domain


def main(domain, python_version, nuke):
    domain = ensure_domain(domain)
    project = Project(domain, python_version)
    project.sanity_checks(nuke=nuke)
    project.virtualenv.create(nuke=nuke)
    project.create_webapp(nuke=nuke)
    project.add_static_file_mappings()
    project.webapp.reload()

    print(snakesay(dedent(
        '''
        All done!
        - Your site is now live at https://{domain}
        - Your web app config screen is here: https://www.pythonanywhere.com/user/{username}/webapps/{mangled_domain}
        '''.format(
            domain=domain,
            username=getpass.getuser().lower(),
            mangled_domain=domain.replace('.', '_')
        )
    )))




if __name__ == '__main__':
    arguments = docopt(__doc__)
    main(arguments['--domain'], arguments['--python'], nuke=arguments.get('--nuke'))



#!C:\b\abs_a3b8nwbdr0\croots\recipe\pythonanywhere_1663667586853\_h_env\python.exe
"""Reloads the given site

Usage:
  pa_reload_webapp.py <domain>

Options:
  <domain>              Domain name, eg www.mydomain.com
"""

from docopt import docopt

from pythonanywhere.api.webapp import Webapp
from pythonanywhere.snakesay import snakesay


def main(domain_name):
    webapp = Webapp(domain_name)
    webapp.reload()
    print(snakesay(
        f"{domain_name} has been reloaded"
    ))


if __name__ == '__main__':
    arguments = docopt(__doc__)
    main(arguments['<domain>'])
